![PyPI - Python Version](https://img.shields.io/pypi/pyversions/wagtail-cjkcms)
[![GitHub license](https://img.shields.io/github/license/cjkpl/wagtail-cjkcms)](https://github.com/cjkpl/wagtail-cjkcms/blob/main/LICENSE)
[![GitHub issues](https://img.shields.io/github/issues/cjkpl/wagtail-cjkcms)](https://github.com/cjkpl/wagtail-cjkcms/issues) 

CMS system for Wagtail 4.x, with support for Bootstrap/MDBootstrap 5.x. Forked from and based on [Wagtail CRX](https://github.com/coderedcorp/coderedcms) - an excellent CMS by [CodeRed](https://www.coderedcorp.com/).

## Summary

Out of the box, CjkCMS provides your project with generic, reusable pages:
`ArticleIndex`, `Article`, `WebPage` which you can use in your project, or extend with additional functionality. CjkCMS pages provide you with a generic "body" section and, using `wagtail-seo` package, a basic SEO functionality.

## Documentation
For documentation see here: [Docs](https://github.com/cjkpl/wagtail-cjkcms/blob/main/docs/index.md)

For a quick overview, see the [quick start guide](https://github.com/cjkpl/wagtail-cjkcms/blob/main/docs/quick-start.md)

For detailed installation instructions, see the [installation guide](https://github.com/cjkpl/wagtail-cjkcms/blob/main/docs/installation.md)

## Testing
### running pytest from devsite folder:
pytest ../wagtail-cjkcms/cjkcms --ds=devsite.settings.dev --doctest-modules --durations=0

### running pytest from testproject folder:
pytest ../cjkcms --ds=testproject.settings.dev --doctest-modules --durations=0

## Contact & support
Please use [Github's Issue Tracker](https://github.com/cjkpl/wagtail-cjkcms/issues) to report bugs, request features, or request support.